.. _indent-name:

!!!!!!
indent
!!!!!!

.. meta::
   :keywords: indent, indentation

.. index:: indent, indentation

.. _indent-title:

Indentation
###########
If there are a number of spaces (or tabs) before
all of the xrst documentation for a page,
those characters are not included in the xrst output.
This enables one to indent the
xrst so it is grouped with the proper code block in the source.
An error message will result if
you use mix tabs and spaces for the indentation.

.. contents::
   :local:

.. _indent@Example:

Example
*******
:ref:`indent_example-name`, and
:ref:`comment_ch_example@Indent`.
